summaryrefslogtreecommitdiffstats
path: root/kopete/protocols/oscar/icq
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-18 18:33:51 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-18 18:33:51 -0600
commit089118c18533dfa3e6ce5065dbebdd4db94051f1 (patch)
treece014fb2326a80fcfafa2362b7ff88486aa17c96 /kopete/protocols/oscar/icq
parent83677e35509b4dafac63b76995652bdf3b49f209 (diff)
downloadtdenetwork-089118c18533dfa3e6ce5065dbebdd4db94051f1.tar.gz
tdenetwork-089118c18533dfa3e6ce5065dbebdd4db94051f1.zip
Rename old tq methods that no longer need a unique name
Diffstat (limited to 'kopete/protocols/oscar/icq')
-rw-r--r--kopete/protocols/oscar/icq/icqaccount.cpp28
-rw-r--r--kopete/protocols/oscar/icq/icqaccount.h2
-rw-r--r--kopete/protocols/oscar/icq/icqcontact.cpp30
-rw-r--r--kopete/protocols/oscar/icq/icqpresence.cpp26
-rw-r--r--kopete/protocols/oscar/icq/icqpresence.h14
-rw-r--r--kopete/protocols/oscar/icq/icqprotocol.cpp10
-rw-r--r--kopete/protocols/oscar/icq/icqreadaway.cpp6
-rw-r--r--kopete/protocols/oscar/icq/ui/icqadd.ui4
-rw-r--r--kopete/protocols/oscar/icq/ui/icqauthreplyui.ui4
-rw-r--r--kopete/protocols/oscar/icq/ui/icqeditaccountui.ui6
-rw-r--r--kopete/protocols/oscar/icq/ui/icqgeneralinfo.ui4
-rw-r--r--kopete/protocols/oscar/icq/ui/icqinterestinfowidget.ui2
-rw-r--r--kopete/protocols/oscar/icq/ui/icqotherinfowidget.ui2
-rw-r--r--kopete/protocols/oscar/icq/ui/icqsearchbase.ui8
-rw-r--r--kopete/protocols/oscar/icq/ui/icquserinfowidget.cpp8
-rw-r--r--kopete/protocols/oscar/icq/ui/icqworkinfowidget.ui2
16 files changed, 78 insertions, 78 deletions
diff --git a/kopete/protocols/oscar/icq/icqaccount.h b/kopete/protocols/oscar/icq/icqaccount.h
index a5335dbc..f3a62c73 100644
--- a/kopete/protocols/oscar/icq/icqaccount.h
+++ b/kopete/protocols/oscar/icq/icqaccount.h
@@ -84,7 +84,7 @@ private:
void setPresenceType( ICQ::Presence::Type, const TQString &awayMessage = TQString() );
void setPresenceTarget( const ICQ::Presence &presence, const TQString &message = TQString() );
- //const unsigned long fulltqStatus( const unsigned long plaintqStatus );
+ //const unsigned long fullStatus( const unsigned long plainStatus );
private slots:
void slotToggleInvisible();
diff --git a/kopete/protocols/oscar/icq/icqcontact.cpp b/kopete/protocols/oscar/icq/icqcontact.cpp
index 30563ae0..d5f1245c 100644
--- a/kopete/protocols/oscar/icq/icqcontact.cpp
+++ b/kopete/protocols/oscar/icq/icqcontact.cpp
@@ -103,7 +103,7 @@ void ICQContact::updateSSIItem()
setOnlineStatus( mProtocol->statusManager()->waitingForAuth() );
if ( m_ssiItem.type() != 0xFFFF && m_ssiItem.waitingAuth() == false &&
- onlinetqStatus() == Kopete::OnlineStatus::Unknown )
+ onlineStatus() == Kopete::OnlineStatus::Unknown )
{
//make sure they're offline
setOnlineStatus( ICQ::Presence( ICQ::Presence::Offline, ICQ::Presence::Visible ).toOnlineStatus() );
@@ -121,8 +121,8 @@ void ICQContact::userInfoUpdated( const TQString& contact, const UserDetails& de
if ( !isOnline() )
removeProperty( mProtocol->awayMessage );
- kdDebug( OSCAR_ICQ_DEBUG ) << k_funcinfo << "extendedStatus is " << details.extendedtqStatus() << endl;
- ICQ::Presence presence = ICQ::Presence::fromOscartqStatus( details.extendedtqStatus() & 0xffff );
+ kdDebug( OSCAR_ICQ_DEBUG ) << k_funcinfo << "extendedStatus is " << details.extendedStatus() << endl;
+ ICQ::Presence presence = ICQ::Presence::fromOscarStatus( details.extendedStatus() & 0xffff );
setOnlineStatus( presence.toOnlineStatus() );
// ICQ does not support status messages for state Online
@@ -133,7 +133,7 @@ void ICQContact::userInfoUpdated( const TQString& contact, const UserDetails& de
}
else
{
- if ( ICQ::Presence::fromOnlineStatus( account()->myself()->onlinetqStatus() ).visibility() == ICQ::Presence::Visible )
+ if ( ICQ::Presence::fromOnlineStatus( account()->myself()->onlineStatus() ).visibility() == ICQ::Presence::Visible )
{
switch ( presence.type() )
{
@@ -561,27 +561,27 @@ void ICQContact::slotContactChanged(const UserInfo &u)
else
removeProperty(mProtocol->clientFeatures);
- unsigned int newtqStatus = 0;
+ unsigned int newStatus = 0;
mInvisible = (mInfo.icqextstatus & ICQ_STATUS_IS_INVIS);
if (mInfo.icqextstatus & ICQ_STATUS_IS_FFC)
- newtqStatus = OSCAR_FFC;
+ newStatus = OSCAR_FFC;
else if (mInfo.icqextstatus & ICQ_STATUS_IS_DND)
- newtqStatus = OSCAR_DND;
+ newStatus = OSCAR_DND;
else if (mInfo.icqextstatus & ICQ_STATUS_IS_OCC)
- newtqStatus = OSCAR_OCC;
+ newStatus = OSCAR_OCC;
else if (mInfo.icqextstatus & ICQ_STATUS_IS_NA)
- newtqStatus = OSCAR_NA;
+ newStatus = OSCAR_NA;
else if (mInfo.icqextstatus & ICQ_STATUS_IS_AWAY)
- newtqStatus = OSCAR_AWAY;
+ newStatus = OSCAR_AWAY;
else
- newtqStatus = OSCAR_ONLINE;
+ newStatus = OSCAR_ONLINE;
if (this != account()->myself())
{
- if(newtqStatus != onlinetqStatus().internalStatus())
+ if(newStatus != onlineStatus().internalStatus())
{
- if(newtqStatus != OSCAR_ONLINE) // if user changed to some state other than online
+ if(newStatus != OSCAR_ONLINE) // if user changed to some state other than online
{
mAccount->engine()->requestAwayMessage(this);
}
@@ -592,7 +592,7 @@ void ICQContact::slotContactChanged(const UserInfo &u)
}
}
- settqStatus(newtqStatus);
+ setStatus(newStatus);
}
void ICQContact::slotOffgoingBuddy(TQString sender)
@@ -655,7 +655,7 @@ TQPtrList<KAction> *ICQContact::customContextMenuActions()
/*
TQString awTxt;
TQString awIcn;
- unsigned int status = onlinetqStatus().internalStatus();
+ unsigned int status = onlineStatus().internalStatus();
if (status >= 15)
status -= 15; // get rid of invis addon
switch(status)
diff --git a/kopete/protocols/oscar/icq/icqpresence.cpp b/kopete/protocols/oscar/icq/icqpresence.cpp
index 520153a6..b0a051d7 100644
--- a/kopete/protocols/oscar/icq/icqpresence.cpp
+++ b/kopete/protocols/oscar/icq/icqpresence.cpp
@@ -49,7 +49,7 @@ struct PresenceTypeData
static const PresenceTypeData *all();
static const PresenceTypeData &forType( Presence::Type type );
- static const PresenceTypeData &fortqStatus( unsigned long status );
+ static const PresenceTypeData &forStatus( unsigned long status );
static const PresenceTypeData &forOnlineStatusType( const Kopete::OnlineStatus::StatusType statusType );
};
@@ -89,7 +89,7 @@ const PresenceTypeData &PresenceTypeData::forType( Presence::Type type )
return array[0];
}
-const PresenceTypeData &PresenceTypeData::fortqStatus( unsigned long status )
+const PresenceTypeData &PresenceTypeData::forStatus( unsigned long status )
{
const PresenceTypeData *array = all();
for ( uint n = 0; n < Presence::TypeCount; ++n )
@@ -216,12 +216,12 @@ Kopete::OnlineStatus OnlineStatusManager::onlineStatusOf( const Presence &presen
return d->invisibleStatusList[ presence.type() ];
}
-Kopete::OnlineStatus OnlineStatusManager::connectingtqStatus()
+Kopete::OnlineStatus OnlineStatusManager::connectingStatus()
{
return d->connecting;
}
-Kopete::OnlineStatus OnlineStatusManager::unknowntqStatus()
+Kopete::OnlineStatus OnlineStatusManager::unknownStatus()
{
return d->unknown;
}
@@ -258,31 +258,31 @@ Kopete::OnlineStatus Presence::toOnlineStatus() const
}
-unsigned long Presence::toOscartqStatus() const
+unsigned long Presence::toOscarStatus() const
{
- unsigned long basictqStatus = basicOscartqStatus();
+ unsigned long basicStatus = basicOscarStatus();
if ( _visibility == Invisible )
- basictqStatus |= StatusCode::INVISIBLE;
- return basictqStatus;
+ basicStatus |= StatusCode::INVISIBLE;
+ return basicStatus;
}
-Presence Presence::fromOscartqStatus( unsigned long code )
+Presence Presence::fromOscarStatus( unsigned long code )
{
- Type type = typeFromOscartqStatus( code & ~StatusCode::INVISIBLE );
+ Type type = typeFromOscarStatus( code & ~StatusCode::INVISIBLE );
bool invisible = (code & StatusCode::INVISIBLE) == StatusCode::INVISIBLE;
return Presence( type, invisible ? Invisible : Visible );
}
-unsigned long Presence::basicOscartqStatus() const
+unsigned long Presence::basicOscarStatus() const
{
const PresenceTypeData &data = PresenceTypeData::forType( _type );
return data.setFlag;
}
-Presence::Type Presence::typeFromOscartqStatus( unsigned long status )
+Presence::Type Presence::typeFromOscarStatus( unsigned long status )
{
- const PresenceTypeData &data = PresenceTypeData::fortqStatus( status );
+ const PresenceTypeData &data = PresenceTypeData::forStatus( status );
return data.type;
}
diff --git a/kopete/protocols/oscar/icq/icqpresence.h b/kopete/protocols/oscar/icq/icqpresence.h
index 360cadeb..d7ef9ed2 100644
--- a/kopete/protocols/oscar/icq/icqpresence.h
+++ b/kopete/protocols/oscar/icq/icqpresence.h
@@ -78,8 +78,8 @@ public:
~OnlineStatusManager();
ICQ::Presence presenceOf( uint internalStatus );
Kopete::OnlineStatus onlineStatusOf( const ICQ::Presence &presence );
- Kopete::OnlineStatus connectingtqStatus();
- Kopete::OnlineStatus unknowntqStatus();
+ Kopete::OnlineStatus connectingStatus();
+ Kopete::OnlineStatus unknownStatus();
Kopete::OnlineStatus waitingForAuth();
private:
@@ -117,23 +117,23 @@ public:
Kopete::OnlineStatus toOnlineStatus() const;
/**
- * Get the status code to pass to liboscar to set us to this tqStatus.
+ * Get the status code to pass to liboscar to set us to this Status.
* @note This is not the opposite of fromOnlineStatus(). The set and get codes don't match.
*/
- unsigned long toOscartqStatus() const;
+ unsigned long toOscarStatus() const;
/**
* Get the status a contact is at based on liboscar's view of its status.
* @note This is not the opposite of toOnlineStatus().
*/
- static Presence fromOscartqStatus( unsigned long code );
+ static Presence fromOscarStatus( unsigned long code );
bool operator==( const Presence &other ) const { return other._type == _type && other._visibility == _visibility; }
bool operator!=( const Presence &other ) const { return !(*this == other); }
private:
- unsigned long basicOscartqStatus() const;
- static Type typeFromOscartqStatus( unsigned long status );
+ unsigned long basicOscarStatus() const;
+ static Type typeFromOscarStatus( unsigned long status );
private:
Type _type;
Visibility _visibility;
diff --git a/kopete/protocols/oscar/icq/icqprotocol.cpp b/kopete/protocols/oscar/icq/icqprotocol.cpp
index dad58726..9e85c1ad 100644
--- a/kopete/protocols/oscar/icq/icqprotocol.cpp
+++ b/kopete/protocols/oscar/icq/icqprotocol.cpp
@@ -66,7 +66,7 @@ K_EXPORT_COMPONENT_FACTORY( kopete_icq, ICQProtocolFactory( "kopete_icq" ) )
ICQProtocolHandler::ICQProtocolHandler() : Kopete::MimeTypeHandler(false)
{
- registerAsMimeHandler(TQString::tqfromLatin1("application/x-icq"));
+ registerAsMimeHandler(TQString::fromLatin1("application/x-icq"));
}
void ICQProtocolHandler::handleURL(const TQString &mimeType, const KURL & url) const
@@ -219,7 +219,7 @@ void ICQProtocol::initGenders()
void ICQProtocol::initCountries()
{
mCountries.insert(0, ""); // unspecified
- KLocale *kl = KGlobal::locale(); //KLocale(TQString::tqfromLatin1("kopete"));
+ KLocale *kl = KGlobal::locale(); //KLocale(TQString::fromLatin1("kopete"));
mCountries.insert(93, kl->twoAlphaToCountryName("af"));
mCountries.insert(355, kl->twoAlphaToCountryName("al"));
@@ -468,7 +468,7 @@ void ICQProtocol::initCountries()
void ICQProtocol::initLang()
{
- KLocale *kl = KGlobal::locale(); //KLocale(TQString::tqfromLatin1("kopete"));
+ KLocale *kl = KGlobal::locale(); //KLocale(TQString::fromLatin1("kopete"));
mLanguages.insert(0 , "");
mLanguages.insert(1 , kl->twoAlphaToLanguageName("ar") /*i18n("Arabic")*/);
@@ -775,8 +775,8 @@ Kopete::Contact *ICQProtocol::deserializeContact( Kopete::MetaContact *metaConta
if ( serializedData.contains( "ssi_waitingAuth" ) )
{
- TQString authtqStatus = serializedData["ssi_waitingAuth"];
- if ( authtqStatus == "true" )
+ TQString authStatus = serializedData["ssi_waitingAuth"];
+ if ( authStatus == "true" )
ssiWaitingAuth = true;
}
diff --git a/kopete/protocols/oscar/icq/icqreadaway.cpp b/kopete/protocols/oscar/icq/icqreadaway.cpp
index 94eaa063..abbc8eb2 100644
--- a/kopete/protocols/oscar/icq/icqreadaway.cpp
+++ b/kopete/protocols/oscar/icq/icqreadaway.cpp
@@ -37,7 +37,7 @@ ICQReadAway::ICQReadAway(ICQContact *c, TQWidget *parent, const char* name)
mAccount = static_cast<ICQAccount*>(c->account());
mContact = c;
- setCaption(i18n("'%2' Message for %1").tqarg(c->displayName()).tqarg(c->onlinetqStatus().description()));
+ setCaption(i18n("'%2' Message for %1").tqarg(c->displayName()).tqarg(c->onlineStatus().description()));
TQVBox *mMainWidget = makeVBoxMainWidget();
@@ -74,12 +74,12 @@ void ICQReadAway::slotFetchAwayMessage()
mAccount->engine()->requestAwayMessage(mContact);
- setCaption(i18n("Fetching '%2' Message for %1...").tqarg(mContact->displayName()).tqarg(mContact->onlinetqStatus().description()));
+ setCaption(i18n("Fetching '%2' Message for %1...").tqarg(mContact->displayName()).tqarg(mContact->onlineStatus().description()));
} // END slotFetchAwayMessage()
void ICQReadAway::slotAwayMessageChanged()
{
- setCaption(i18n("'%2' Message for %1").tqarg(mContact->displayName()).tqarg(mContact->onlinetqStatus().description()));
+ setCaption(i18n("'%2' Message for %1").tqarg(mContact->displayName()).tqarg(mContact->onlineStatus().description()));
awayMessageBrowser->setText(mContact->awayMessage());
awayMessageBrowser->setDisabled(false);
diff --git a/kopete/protocols/oscar/icq/ui/icqadd.ui b/kopete/protocols/oscar/icq/ui/icqadd.ui
index 5ac8d973..6ae1f092 100644
--- a/kopete/protocols/oscar/icq/ui/icqadd.ui
+++ b/kopete/protocols/oscar/icq/ui/icqadd.ui
@@ -71,7 +71,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>47</width>
<height>26</height>
@@ -101,7 +101,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>20</height>
diff --git a/kopete/protocols/oscar/icq/ui/icqauthreplyui.ui b/kopete/protocols/oscar/icq/ui/icqauthreplyui.ui
index 61fc84cb..370bef8b 100644
--- a/kopete/protocols/oscar/icq/ui/icqauthreplyui.ui
+++ b/kopete/protocols/oscar/icq/ui/icqauthreplyui.ui
@@ -68,7 +68,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>50</width>
<height>20</height>
@@ -131,7 +131,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>220</width>
<height>21</height>
diff --git a/kopete/protocols/oscar/icq/ui/icqeditaccountui.ui b/kopete/protocols/oscar/icq/ui/icqeditaccountui.ui
index 1bc5d379..541308e2 100644
--- a/kopete/protocols/oscar/icq/ui/icqeditaccountui.ui
+++ b/kopete/protocols/oscar/icq/ui/icqeditaccountui.ui
@@ -149,7 +149,7 @@
<verstretch>0</verstretch>
</sizepolicy>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>0</width>
<height>0</height>
@@ -183,7 +183,7 @@ If you do not currently have an ICQ account, please click the button to create o
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>40</height>
@@ -372,7 +372,7 @@ If you do not currently have an ICQ account, please click the button to create o
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>40</height>
diff --git a/kopete/protocols/oscar/icq/ui/icqgeneralinfo.ui b/kopete/protocols/oscar/icq/ui/icqgeneralinfo.ui
index c48e8ff9..1af12007 100644
--- a/kopete/protocols/oscar/icq/ui/icqgeneralinfo.ui
+++ b/kopete/protocols/oscar/icq/ui/icqgeneralinfo.ui
@@ -331,7 +331,7 @@
<verstretch>0</verstretch>
</sizepolicy>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>125</width>
<height>0</height>
@@ -579,7 +579,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>21</width>
<height>20</height>
diff --git a/kopete/protocols/oscar/icq/ui/icqinterestinfowidget.ui b/kopete/protocols/oscar/icq/ui/icqinterestinfowidget.ui
index 009780f0..1dd7134b 100644
--- a/kopete/protocols/oscar/icq/ui/icqinterestinfowidget.ui
+++ b/kopete/protocols/oscar/icq/ui/icqinterestinfowidget.ui
@@ -103,7 +103,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>220</height>
diff --git a/kopete/protocols/oscar/icq/ui/icqotherinfowidget.ui b/kopete/protocols/oscar/icq/ui/icqotherinfowidget.ui
index d5d77c09..088fc302 100644
--- a/kopete/protocols/oscar/icq/ui/icqotherinfowidget.ui
+++ b/kopete/protocols/oscar/icq/ui/icqotherinfowidget.ui
@@ -26,7 +26,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>30</height>
diff --git a/kopete/protocols/oscar/icq/ui/icqsearchbase.ui b/kopete/protocols/oscar/icq/ui/icqsearchbase.ui
index 140f17fa..161444f6 100644
--- a/kopete/protocols/oscar/icq/ui/icqsearchbase.ui
+++ b/kopete/protocols/oscar/icq/ui/icqsearchbase.ui
@@ -114,7 +114,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>41</width>
<height>190</height>
@@ -162,7 +162,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>105</height>
@@ -328,7 +328,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>16</height>
@@ -345,7 +345,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>166</width>
<height>20</height>
diff --git a/kopete/protocols/oscar/icq/ui/icquserinfowidget.cpp b/kopete/protocols/oscar/icq/ui/icquserinfowidget.cpp
index 1eb1c934..44fd5afd 100644
--- a/kopete/protocols/oscar/icq/ui/icquserinfowidget.cpp
+++ b/kopete/protocols/oscar/icq/ui/icquserinfowidget.cpp
@@ -47,28 +47,28 @@ ICQUserInfoWidget::ICQUserInfoWidget( TQWidget * parent, const char * name )
TQFrame* genInfo = addPage( i18n( "General Info" ),
i18n( "General ICQ Information" ),
- KGlobal::iconLoader()->loadIcon( TQString::tqfromLatin1( "identity" ), KIcon::Desktop ) );
+ KGlobal::iconLoader()->loadIcon( TQString::fromLatin1( "identity" ), KIcon::Desktop ) );
TQVBoxLayout* genLayout = new TQVBoxLayout( genInfo );
m_genInfoWidget = new ICQGeneralInfoWidget( genInfo, "Basic Information" );
genLayout->addWidget( m_genInfoWidget );
TQFrame* workInfo = addPage( i18n( "Work Info" ),
i18n( "Work Information" ),
- KGlobal::iconLoader()->loadIcon( TQString::tqfromLatin1( "attach" ), KIcon::Desktop ) );
+ KGlobal::iconLoader()->loadIcon( TQString::fromLatin1( "attach" ), KIcon::Desktop ) );
TQVBoxLayout* workLayout = new TQVBoxLayout( workInfo );
m_workInfoWidget = new ICQWorkInfoWidget( workInfo, "Work Information" );
workLayout->addWidget( m_workInfoWidget );
TQFrame* otherInfo = addPage( i18n( "Other Info" ),
i18n( "Other ICQ Information" ),
- KGlobal::iconLoader()->loadIcon( TQString::tqfromLatin1( "email" ), KIcon::Desktop ) );
+ KGlobal::iconLoader()->loadIcon( TQString::fromLatin1( "email" ), KIcon::Desktop ) );
TQVBoxLayout* otherLayout = new TQVBoxLayout( otherInfo );
m_otherInfoWidget = new ICQOtherInfoWidget( otherInfo, "Other Information" );
otherLayout->addWidget( m_otherInfoWidget );
TQFrame* interestInfo = addPage( i18n( "Interest Info" ),
i18n( "Interest" ),
- KGlobal::iconLoader()->loadIcon( TQString::tqfromLatin1( "email" ), KIcon::Desktop ) );
+ KGlobal::iconLoader()->loadIcon( TQString::fromLatin1( "email" ), KIcon::Desktop ) );
TQVBoxLayout* interestLayout = new TQVBoxLayout( interestInfo );
m_interestInfoWidget = new ICQInterestInfoWidget( interestInfo, "Other Information" );
interestLayout->addWidget( m_interestInfoWidget );
diff --git a/kopete/protocols/oscar/icq/ui/icqworkinfowidget.ui b/kopete/protocols/oscar/icq/ui/icqworkinfowidget.ui
index 4707dbe8..8f243f20 100644
--- a/kopete/protocols/oscar/icq/ui/icqworkinfowidget.ui
+++ b/kopete/protocols/oscar/icq/ui/icqworkinfowidget.ui
@@ -236,7 +236,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>70</height>
diff --git a/kopete/protocols/oscar/icq/icqaccount.cpp b/kopete/protocols/oscar/icq/icqaccount.cpp
index 245e365c..9d996724 100644
--- a/kopete/protocols/oscar/icq/icqaccount.cpp
+++ b/kopete/protocols/oscar/icq/icqaccount.cpp
@@ -50,9 +50,9 @@ ICQMyselfContact::ICQMyselfContact( ICQAccount *acct ) : OscarMyselfContact( acc
void ICQMyselfContact::userInfoUpdated()
{
- DWORD extendedtqStatus = details().extendedtqStatus();
- kdDebug( OSCAR_ICQ_DEBUG ) << k_funcinfo << "extendedStatus is " << TQString::number( extendedtqStatus, 16 ) << endl;
- ICQ::Presence presence = ICQ::Presence::fromOscartqStatus( extendedtqStatus & 0xffff );
+ DWORD extendedStatus = details().extendedStatus();
+ kdDebug( OSCAR_ICQ_DEBUG ) << k_funcinfo << "extendedStatus is " << TQString::number( extendedStatus, 16 ) << endl;
+ ICQ::Presence presence = ICQ::Presence::fromOscarStatus( extendedStatus & 0xffff );
setOnlineStatus( presence.toOnlineStatus() );
setProperty( Kopete::Global::Properties::self()->awayMessage(), static_cast<ICQAccount*>( account() )->engine()->statusMessage() );
}
@@ -100,7 +100,7 @@ ICQAccount::ICQAccount(Kopete::Protocol *parent, TQString accountID, const char
{
kdDebug(14153) << k_funcinfo <<
"sending status to reflect HideIP and WebAware settings" << endl;
- //settqStatus(mtqStatus, TQString());
+ //setStatus(mStatus, TQString());
}*/
}
@@ -116,7 +116,7 @@ ICQProtocol* ICQAccount::protocol()
ICQ::Presence ICQAccount::presence()
{
- return ICQ::Presence::fromOnlineStatus( myself()->onlinetqStatus() );
+ return ICQ::Presence::fromOnlineStatus( myself()->onlineStatus() );
}
@@ -150,21 +150,21 @@ void ICQAccount::connectWithPassword( const TQString &password )
kdDebug(14153) << k_funcinfo << "accountId='" << accountId() << "'" << endl;
- Kopete::OnlineStatus status = initialtqStatus();
+ Kopete::OnlineStatus status = initialStatus();
if ( status == Kopete::OnlineStatus() &&
status.status() == Kopete::OnlineStatus::Unknown )
//use default online in case of invalid online status for connecting
status = Kopete::OnlineStatus( Kopete::OnlineStatus::Online );
ICQ::Presence pres = ICQ::Presence::fromOnlineStatus( status );
bool accountIsOffline = ( presence().type() == ICQ::Presence::Offline ||
- myself()->onlinetqStatus() == protocol()->statusManager()->connectingtqStatus() );
+ myself()->onlineStatus() == protocol()->statusManager()->connectingStatus() );
if ( accountIsOffline )
{
- myself()->setOnlineStatus( protocol()->statusManager()->connectingtqStatus() );
+ myself()->setOnlineStatus( protocol()->statusManager()->connectingStatus() );
TQString icqNumber = accountId();
kdDebug(14153) << k_funcinfo << "Logging in as " << icqNumber << endl ;
- TQString server = configGroup()->readEntry( "Server", TQString::tqfromLatin1( "login.oscar.aol.com" ) );
+ TQString server = configGroup()->readEntry( "Server", TQString::fromLatin1( "login.oscar.aol.com" ) );
uint port = configGroup()->readNumEntry( "Port", 5190 );
Connection* c = setupConnection( server, port );
@@ -172,15 +172,15 @@ void ICQAccount::connectWithPassword( const TQString &password )
Oscar::Settings* oscarSettings = engine()->clientSettings();
oscarSettings->setWebAware( configGroup()->readBoolEntry( "WebAware", false ) );
oscarSettings->setHideIP( configGroup()->readBoolEntry( "HideIP", true ) );
- //FIXME: also needed for the other call to settqStatus (in setPresenceTarget)
- DWORD status = pres.toOscartqStatus();
+ //FIXME: also needed for the other call to setStatus (in setPresenceTarget)
+ DWORD status = pres.toOscarStatus();
if ( !mHideIP )
status |= ICQ::StatusCode::SHOWIP;
if ( mWebAware )
status |= ICQ::StatusCode::WEBAWARE;
- engine()->settqStatus( status, mInitialStatusMessage );
+ engine()->setStatus( status, mInitialStatusMessage );
updateVersionUpdaterStamp();
engine()->start( server, port, accountId(), password );
engine()->connectToServer( c, server, true /* doAuth */ );
@@ -331,7 +331,7 @@ void ICQAccount::setPresenceTarget( const ICQ::Presence &newPres, const TQString
{
bool targetIsOffline = (newPres.type() == ICQ::Presence::Offline);
bool accountIsOffline = ( presence().type() == ICQ::Presence::Offline ||
- myself()->onlinetqStatus() == protocol()->statusManager()->connectingtqStatus() );
+ myself()->onlineStatus() == protocol()->statusManager()->connectingStatus() );
if ( targetIsOffline )
{
@@ -346,7 +346,7 @@ void ICQAccount::setPresenceTarget( const ICQ::Presence &newPres, const TQString
}
else
{
- engine()->settqStatus( newPres.toOscartqStatus(), message );
+ engine()->setStatus( newPres.toOscarStatus(), message );
}
}